/*----------------------------------------------------------------------------
 Copyright:      Radig Ulrich  mailto: mail@ulrichradig.de
 Author:         Radig Ulrich
 Remarks:
 known Problems: none
 Version:        24.10.2007
 Description:    Timer Routinen

 Dieses Programm ist freie Software. Sie knnen es unter den Bedingungen der 
 GNU General Public License, wie von der Free Software Foundation verffentlicht, 
 weitergeben und/oder modifizieren, entweder gem Version 2 der Lizenz oder 
 (nach Ihrer Option) jeder spteren Version. 

 Die Verffentlichung dieses Programms erfolgt in der Hoffnung, 
 da es Ihnen von Nutzen sein wird, aber OHNE IRGENDEINE GARANTIE, 
 sogar ohne die implizite Garantie der MARKTREIFE oder der VERWENDBARKEIT 
 FR EINEN BESTIMMTEN ZWECK. Details finden Sie in der GNU General Public License. 

 Sie sollten eine Kopie der GNU General Public License zusammen mit diesem 
 Programm erhalten haben. 
 Falls nicht, schreiben Sie an die Free Software Foundation, 
 Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA. 
------------------------------------------------------------------------------*/
#include "config.h"
#include "timer.h"
#include <avr/interrupt.h>

volatile unsigned long time;
volatile unsigned long sub_ticks = 0;

//----------------------------------------------------------------------------
//Diese Routine startet und inizialisiert den Timer
void timer_init (void)
{
	// Quarz: 8MHz = 16000000 Hz / Prescaler 1024 =  Taktzyklen
	// 15625 / 125 =  125 Timerberlufe pro Sekunde
	// Da timer berlauf bei 256 => Timer auf 131 (0x83)vorladen...

	TIMSK = (1<<TOIE0);
	TCCR0 = (1<<CS00 | 0<<CS01 | 1<<CS02);
	TCNT0 = 0x83;

return;
};

//----------------------------------------------------------------------------
//Timer Interrupt
ISR (TIMER0_OVF_vect)
{
	// reload timer for next cycle
	TCNT0 = 0x83;

	sub_ticks++;

	if(sub_ticks>=125)
	{
		sub_ticks=0;
		time++;

		// reset second counter on midnight
		if(time == 86400){
			time = 0;
		}
	}
}

